@@ -150,13 +150,13 @@ def product_stats_section(a, df, rep, all_stats, doc):
                     doc.line("div", tags, klass="product_tags")
                 with doc.tag("table", style="width: 100%"):
                     with doc.tag("tr"):
-                        doc.line("td", nbsp("\u25B6 Results for this Job: "), style="width: 10%")
+                        doc.line("td", nbsp("\u25B6 Results for this Job: "), klass="product_field")
                         with doc.tag("td"):
                             product_stat_bar(doc, row["product_match_rate"], row["product_error_rate"])
                     pstats = product_stats_from_all_stats(all_stats, pid)
                     if not pstats.empty:
                         with doc.tag("tr"):
-                            doc.line("td", nbsp("\u25B6 Overall Results for this Product: "))
+                            doc.line("td", nbsp("\u25B6 Overall Results for this Product: "), klass="product_field")
                             with doc.tag("td"):
                                 product_stat_bar(doc, pstats["product_match_rate"].iloc[0], pstats["product_error_rate"].iloc[0])
     doc.line("h3", "More Statistics")
@@ -207,7 +207,7 @@ def distribution_diagrams(a, rep, all_stats):
             pstats['attribute_name'] = pstats['attribute_name'].str.replace(r"\[(\d+)\]", '[*]', regex=True)
             pstats = pstats.drop_duplicates(subset="attribute_name")
             numattr = len(pstats.loc[pstats['product_name'] == p])
-            x = pstats.loc[pstats['product_name'] == p]['attribute_fill_rate'].to_numpy() * 100.0
+            x = pstats.loc[pstats['product_name'] == p]['attribute_fill_rate'].to_numpy()
             arr = plt.hist(x, 100)
             plt.gcf().set_size_inches(5, 2)
             plt.xlabel('Fill Rate (%)')
@@ -291,7 +291,7 @@ def details_section(a, df, rep, all_stats, doc):
                                 with doc.tag("tr"):
                                     doc.line("td", nbsp("\u25B6 Overall Results for this Attribute: "), klass="attr_field")
                                     with doc.tag("td", klass="attr_field_value"):
-                                        render_attr_bar(doc, astat["attribute_fill_rate"] * 100.0)
+                                        render_attr_bar(doc, astat["attribute_fill_rate"])
                         if isinstance(df, pd.DataFrame) and (row["attribute_type"] == np.dtype("float64")):
                             with doc.tag("tr"):
                                 doc.line("td", nbsp("\u25B6 Attribute Histogram: "), klass="attr_field")
